Changes in XlsxWriter — XlsxWriter Documentation

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »

# Changes in XlsxWriter

This section shows changes and bug fixes in the XlsxWriter module.

## Release 0.1.0 - February 28 2013

- Added the `set_properties()` workbook method for setting document properties.

- Added several new examples programs with documentation. The examples now include:

  > - array_formula.py
  > - cell_indentation.py
  > - datetimes.py
  > - defined_name.py
  > - demo.py
  > - doc_properties.py
  > - headers_footers.py
  > - hello_world.py
  > - merge1.py
  > - tutorial1.py
  > - tutorial2.py
  > - tutorial3.py
  > - unicode_polish_utf8.py
  > - unicode_shift_jis.py

## Release 0.0.9 - February 27 2013

- Added the `define_name()` method to create defined names and ranges in a workbook or worksheet.
- Added the `worksheets()` method as an accessor for the worksheets in a workbook.

## Release 0.0.8 - February 26 2013

- Added the `merge_range()` method to merge worksheet cells.

## Release 0.0.7 - February 25 2013

- Added final page setup methods to complete the page setup section.

  > - print_area()
  > - fit_to_pages()
  > - set_start_page()
  > - set_print_scale()
  > - set_h_pagebreaks()
  > - set_v_pagebreaks()

## Release 0.0.6 - February 22 2013

- Added page setup method.

  > - print_row_col_headers

## Release 0.0.5 - February 21 2013

- Added page setup methods.

  > - repeat_rows()
  > - repeat_columns()

## Release 0.0.4 - February 20 2013

- Added Python 3 support with help from John Evans. Tested with:

  > - Python-2.7.2
  > - Python-2.7.3
  > - Python-3.2
  > - Python-3.3.0

- Added page setup methods.

  > - center_horizontally()
  > - center_vertically()
  > - set_header()
  > - set_footer()
  > - hide_gridlines()

## Release 0.0.3 - February 19 2013

- Added page setup method.

  > - set_margins()

## Release 0.0.2 - February 18 2013

- Added page setup methods.

  > - set_landscape()
  > - set_portrait()
  > - set_page_view()
  > - set_paper()
  > - print_across()

## Release 0.0.1 - February 17 2013

- First public release.

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »